@@ -1,6 +1,8 @@
 use super::super::common;
 use hydrus_api::api_core::adding_tags::TagAction;
+use hydrus_api::wrapper::builders::or_chain_builder::OrChainBuilder;
 use hydrus_api::wrapper::builders::search_builder::SortType;
+use hydrus_api::wrapper::builders::tag_builder::TagBuilder;
 use hydrus_api::wrapper::service::{ServiceName, ServiceType};
 use hydrus_api::wrapper::url::UrlType;
 
@@ -39,6 +41,13 @@ async fn it_searches() {
     hydrus
         .search()
         .add_tag("character:megumin".into())
+        .add_or_chain(
+            OrChainBuilder::new()
+                .add_tag("summer".into())
+                .add_tag("winter".into())
+                .add_tag(TagBuilder::new("inside").negate().build())
+                .build(),
+        )
         .sort_by(SortType::ModifiedTime)
         .run()
         .await
@@ -51,7 +60,7 @@ async fn it_adds_tags() {
     hydrus
         .tagging()
         .add_tag(
-            ServiceName::my_tags(),
+            ServiceName::my_tags().into(),
             TagAction::AddToLocalService,
             "summer".into(),
         )
